Module Name:    src
Committed By:   christos
Date:           Thu Jan 22 19:04:28 UTC 2015

Modified Files:
        src/lib/libutil: pidfile.c

Log Message:
s/basename/bname/


To generate a diff of this commit:
cvs rdiff -u -r1.10 -r1.11 src/lib/libutil/pidfile.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libutil/pidfile.c
diff -u src/lib/libutil/pidfile.c:1.10 src/lib/libutil/pidfile.c:1.11
--- src/lib/libutil/pidfile.c:1.10	Thu Jan 22 11:19:08 2015
+++ src/lib/libutil/pidfile.c	Thu Jan 22 14:04:28 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: pidfile.c,v 1.10 2015/01/22 16:19:08 christos Exp $	*/
+/*	$NetBSD: pidfile.c,v 1.11 2015/01/22 19:04:28 christos Exp $	*/
 
 /*-
  * Copyright (c) 1999 The NetBSD Foundation, Inc.
@@ -31,7 +31,7 @@
 
 #include <sys/cdefs.h>
 #if defined(LIBC_SCCS) && !defined(lint)
-__RCSID("$NetBSD: pidfile.c,v 1.10 2015/01/22 16:19:08 christos Exp $");
+__RCSID("$NetBSD: pidfile.c,v 1.11 2015/01/22 19:04:28 christos Exp $");
 #endif
 
 #include <sys/param.h>
@@ -99,7 +99,7 @@ cleanup_old_pidfile(const char* path)
 }
 
 /* Constructs a name for a pidfile in the default location (/var/run).  If
  * 'basename' is NULL, uses the name of the current program for the name of
  * the pidfile.
  *
  * Returns a pointer to a dynamically-allocatd string containing the absolute
@@ -113,7 +113,7 @@ generate_varrun_path(const char *bname)
 		bname = getprogname();
 
 	/* _PATH_VARRUN includes trailing / */
-	if (asprintf(&path, "%s%s.pid", _PATH_VARRUN, basename) == -1)
+	if (asprintf(&path, "%s%s.pid", _PATH_VARRUN, bname) == -1)
 		return NULL;
 	return path;
 }
@@ -99,7 +99,7 @@ cleanup_old_pidfile(const char* path)
 
 /* Constructs a name for a pidfile in the default location (/var/run).  If
- * 'basename' is NULL, uses the name of the current program for the name of
+ * 'bname' is NULL, uses the name of the current program for the name of
  * the pidfile.
  *

Reply via email to